==> 0.12.7.zip: saneeconomy/SaneEconomyCore/src/main/java/org/appledash/saneeconomy/economy/transaction/Transaction.java <==
package org.appledash.saneeconomy.economy.transaction;

import org.appledash.saneeconomy.economy.economable.Economable;
import org.appledash.saneeconomy.economy.transaction.TransactionReason.AffectedParties;

/**
 * Created by appledash on 9/21/16.
 * Blackjack is best pony.
 */
public class Transaction {
    private final Economable sender;
    private final Economable receiver;
    private final double amount;
    private final TransactionReason reason;

    public Transaction(Economable sender, Economable receiver, double amount, TransactionReason reason) {
        if (amount <= 0.0) {
            throw new IllegalArgumentException("Cannot transact a zero or negative amount!");
        }

        this.sender = sender;
        this.receiver = receiver;
        this.amount = amount;
        this.reason = reason;
    }

    public Economable getSender() {
        return sender;
    }

    public Economable getReceiver() {
        return receiver;
    }

    public double getAmount() {
        return amount;
    }

    public TransactionReason getReason() {
        return reason;
    }

    public boolean isSenderAffected() {
        if (sender == Economable.CONSOLE) {
            return false;
        }

        return (reason.getAffectedParties() == AffectedParties.SENDER) || (reason.getAffectedParties() == AffectedParties.BOTH);
    }

    public boolean isReceiverAffected() {
        if (receiver == Economable.CONSOLE) {
            return false;
        }

        return (reason.getAffectedParties() == AffectedParties.RECEIVER) || (reason.getAffectedParties() == AffectedParties.BOTH);
    }
}

==> 0.16.0.zip: saneeconomy/SaneEconomyCore/src/main/java/org/appledash/saneeconomy/economy/transaction/Transaction.java <==
package org.appledash.saneeconomy.economy.transaction;

import org.appledash.saneeconomy.economy.Currency;
import org.appledash.saneeconomy.economy.economable.Economable;
import org.appledash.saneeconomy.economy.transaction.TransactionReason.AffectedParties;
import org.appledash.saneeconomy.utils.NumberUtils;

import java.math.BigDecimal;

/**
 * Created by appledash on 9/21/16.
 * Blackjack is best pony.
 */
public class Transaction {
    private final Economable sender;
    private final Economable receiver;
    private final BigDecimal amount;
    private final TransactionReason reason;

    public Transaction(Currency currency, Economable sender, Economable receiver, BigDecimal amount, TransactionReason reason) {
        if (amount.compareTo(BigDecimal.ZERO) <= 0) {
            throw new IllegalArgumentException("Cannot transact a zero or negative amount!");
        }


        this.sender = sender;
        this.receiver = receiver;
        this.amount = NumberUtils.filterAmount(currency, amount);
        this.reason = reason;
    }

    public Economable getSender() {
        return sender;
    }

    public Economable getReceiver() {
        return receiver;
    }

    public BigDecimal getAmount() {
        return amount;
    }

    public TransactionReason getReason() {
        return reason;
    }

    public boolean isSenderAffected() {
        if (sender == Economable.CONSOLE) {
            return false;
        }

        return (reason.getAffectedParties() == AffectedParties.SENDER) || (reason.getAffectedParties() == AffectedParties.BOTH);
    }

    public boolean isReceiverAffected() {
        if (receiver == Economable.CONSOLE) {
            return false;
        }

        return (reason.getAffectedParties() == AffectedParties.RECEIVER) || (reason.getAffectedParties() == AffectedParties.BOTH);
    }
}
